==> julia-1.12.2-macaarch64.tar.gz: julia-1.12.2/share/julia/juliac/._juliac-buildscript.jl <==
    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-buildscript A427R7F42H ~ BQoPG}G>                    XcCp0@Js5IN                            juliac-buildscript                    
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H                4                      Gjuliac-buildscript A427R7F42H +R( 7#u9JPi                                B'G\,vke1wŬ6haq
by-\J0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
251120174431Z0/	*H
	1" ){AL
/x39?Æp0[	*Hcd	1N0+2?S#?
v0-	`He  [zy9P:w
-ZpU40[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		lhrS5wwyP7FTIx7BPxjf5w33GHY=
		</data>
		<data>
		nSDeDFt6eec5mgHYUBoHp4866Xc=
		</data>
	</array>
</dict>
</plist>
0
	*H
  +$\ʏN-Nֈ9ogs݄vKKټٚD"h^?沭3DfWWl(@Do1UI1]BK$ kZb_t=qQRRwXWuMJԶ;9ĺWX]ēHL&;Q0ql'd\盍 6Ы0!??<H&7)ӡ:BX0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  ,}4=[/0U>:(=)s20251120174432Z085
00o%,J0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251110174026Z
251222174025Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 q,?
8
tI6Dfsi?Jf+N"Utx˷nΐZ{sh
X@DOZ)fFIri{X.1|@BYFXAǡn+IoEGS6C2;d\[Yz2,Qa*r(mf%
0{X&3D$)ϵ,z ^9l֖=ŢdޮWOY?U#."?MN˘ 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0UTveS{x[+O 0U0
	*H
  g>uA*aZz%IKo

VCCJ f^6tMy(GjUHDeO;7S	̜$)ʓ]Fw|(:@jf_5[>^.Vva-ĝi(e
QPD7t	K(ݙzܾzXz>k4Gc$%$8}p b][s*c7#	Itu0У{r	]
B  !00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSo%,J0	+ 0	*H
	1
*H
	0	*H
	1
251120174432Z0#	*H
	1vH.a/Q $l5!0+*H
	1000A1c$ײr&S0
	*H
  G+ˌFpd1&F5^̨M	uu!m}Eɥ8M$h>ڿhiL%!f&R3]_1&JWIuryUB>3ŵv2
" 3F,T3ߑ2cڂ\JS΁9"e?\:
O-+$BIyB^g3П-3tUjEH,{'%ZS?w4Նh{zw*7;      

==> julia-1.12.3-macaarch64.tar.gz: julia-1.12.3/share/julia/juliac/._juliac-buildscript.jl <==
    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-buildscript A427R7F42H ~ BQoPG}G>                    XcCp0@Js5IN                            juliac-buildscript                    
*Hcd                   
*Hcd
                
subject.OU        
A427R7F42H                4                      Gjuliac-buildscript A427R7F42H +R( 7#u9JPi                                B'G\,vke1wŬ6haq
by-\J0	*H
010
	`He 0	*H
  0>0& ?͗Iz˃Mxs]C0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
210922185510Z
310917000000Z0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0"0
	*H
  0
 ,h!TeqN
(uRDހFg) 0MLnJcLB/}%_K*To0)(4x]#*!FЉ_jq
5-'!@r7v1tpL-^Eb@7\ܥP@
#%E@g{9x43.,&%Ϊ*w_.q;Lz"Mpֆg33Z@Īs\7 00U0 0U#0+iGv	k.@GM^0D+80604+0(http://ocsp.apple.com/ocsp03-applerootca0.U'0%0#!http://crl.apple.com/root.crl0U:ivY7U0U0
*Hcd 0
	*H
  C
YCZ20V&Hc+irH[^&t#3T3"ZظKiΖ
5joΊibmJ9MעԈ3\7D7Dh
{}~̵o=zt}҈1Y`F잹@*a
pJ,Lyc%!#o[ZWEm_doD/oM=xx
V;:+eXԹ02M$9:Z\000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00!u	LrZ=0
	*H
 0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS0
240912150650Z
290913150649Z010
	&,d
A427R7F42H1C0AU:Developer ID Application: Julia Computing LLC (A427R7F42H)10U
A427R7F42H10U
Julia Computing LLC10	UUS0"0
	*H
  0
 IXTVC#$
T'D`qz5c۾Lt<-ލ^R4}Gwb"BϻI٩#5=qQ_Û3(*5%b,4N	#4BMoW_ŦfL8NDJ=u"C[v8`ch%;K3ȏA'}mTl" ߲shCg]v<8i]`2Ea3/ZHLi F0B0U0 0U#0:ivY7U0r+f0d0.+0"http://certs.apple.com/devidg2.der02+0&http://ocsp.apple.com/ocsp03-devidg2010U 00
	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.07++https://www.apple.com/certificateauthority/0U%0
+0UWmDl.?^0U0
*Hcd!20140811000000Z0
*Hcd
 0
	*H
  u8V(j+FmX 0:M<Rz/<q.(ߡz=$Z-h
ׯ(ǁ4SYm$P`Δw,,ؗ'MtD!N
\F
W)ZZKxwME
Y(j9\@DztB@`V**$g߼gy;g~0Lӧ=@X#Y
ӢFZ&N1qHу!ID}ᾡ0/v|req5O+/N1Aҙ100r0^1-0+U$Developer ID Certification Authority10	UG210U

Apple Inc.10	UUS!u	LrZ=0
	`He %0	*H
	1	*H
0	*H
	1
251215123700Z0/	*H
	1" ){AL
/x39?Æp0[	*Hcd	1N0+2?S#?
v0-	`He  [zy9P:w
-ZpU40[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		lhrS5wwyP7FTIx7BPxjf5w33GHY=
		</data>
		<data>
		nSDeDFt6eec5mgHYUBoHp4866Xc=
		</data>
	</array>
</dict>
</plist>
0
	*H
  ';3=(*:UzzDvFN$Tf0*eh_7zyNFI0W5_|sSkԪSp`~wx&hXKxW~o{Ī]_"hK8rB1Wodl3R]['Z"I"t닋J	Vo2D>?щQxak5ҡV1"2A2(Iͦ#^r<êtwP"S^	&x/0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  %:^dsPR +?o68 7qY20251215123700Z0t_X^l5f
00:0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251208174023Z
260119174022Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 PT3HʦY$)4 ꩦ鈤0W ؠ#H4	'Te1sWx.'F%te$L3H}lMUהia$;1kGt_Q3%2YPQ8Qy6\cr<j(O)Wr#0:(2l<Hky$0m_Zm,脥FQiiP˲1ءAT6a W55	I# 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvq!	#ğ=80U0
	*H
  }T[ipT!5]]M+P;"͛*q^}w`"8@I1~StV q=NAp-N¼!~v<Uu=狖U~RZ<ڌXGI΄O_#$V*Ar49֐A{=\ݳӏ<,JY)uC(xq0hYg`A]\"Bbeq
ldʪiG^SI-/C^A~J00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS:0	+ 0	*H
	1
*H
	0	*H
	1
251215123700Z0#	*H
	1(h	9N/Q0+*H
	1000Ӟw!\ _0
	*H
  fx&҅tqZF^r?|,BjC;,UT5=.]
^+Yq^6DE,0})(8U !2\?Ĕm o6KkA)ɰiΔ(7hKNڴH&8lx|+L.i)K#&C3_tnR{VMn9s?I_<5"ށ8;nc)CőV#s      
